summaryrefslogtreecommitdiff
path: root/cached/weather_data.py
diff options
context:
space:
mode:
Diffstat (limited to 'cached/weather_data.py')
-rw-r--r--cached/weather_data.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/cached/weather_data.py b/cached/weather_data.py
index 94a0131..8d49736 100644
--- a/cached/weather_data.py
+++ b/cached/weather_data.py
@@ -41,7 +41,7 @@ class WeatherData:
date: datetime.date # The date
high: float # The predicted high in F
low: float # The predicted low in F
precipitation_inchs: float # Number of inches of precipitation / day
conditions: List[str] # Conditions per ~3h window
most_common_condition: str # The most common condition
icon: str # An icon to represent it
@@ -108,7 +108,7 @@ class CachedWeatherData(persistent.Persistent):
date = dt,
high = float(parsed_json["main"]["temp_max"]),
low = float(parsed_json["main"]["temp_min"]),
- precipitation_inchs = p / 25.4,
+ precipitation_inches = p / 25.4,
conditions = [condition],
most_common_condition = condition,
icon = icon,
@@ -172,7 +172,7 @@ class CachedWeatherData(persistent.Persistent):
date = dt,
high = highs[dt],
low = lows[dt],
- precipitation_inchs = precip[dt] / 25.4,
+ precipitation_inches = precip[dt] / 25.4,
conditions = conditions[dt],
most_common_condition = most_common_condition,
icon = icon
@@ -41,7 +41,7 @@ class WeatherData:
high: float # The predicted high in F
low: float # The predicted low in F
- precipitation_inchs: float # Number of inches of precipitation / day
+ precipitation_inches: float # Number of inches of precipitation / day
conditions: List[str] # Conditions per ~3h window
most_common_condition: str # The most common condition